<?php

namespace Drupal\commerce_easytransac;

use Drupal\commerce_easytransac\Plugin\Commerce\PaymentGateway\MainEasyTransacInterface;
use Drupal\Core\Session\AccountInterface;
use Drupal\user\UserInterface;
use EasyTransac\Core\Services;

/**
 * Provides the interface for the EasyTransac application.
 */
interface ApplicationInterface {

  /**
   * Get the EasyTransac API debug status for the payment gateway.
   *
   * @return bool
   *   The EasyTransac API debug status.
   */
  public function getDebug(): ?bool;

  /**
   * Get the EasyTransac API request timeout for the payment gateway.
   *
   * @return ?int
   *   The EasyTransac API request timeout, or NULL if none set.
   */
  public function getRequestTimeout(): ?int;

  /**
   * Get the EasyTransac API log path for the payment gateway.
   *
   * @return ?string
   *   The EasyTransac API log path, or NULL if none set.
   */
  public function getLogPath(): ?string;

  /**
   * Get the current user.
   */
  public function getCurrentUser(): AccountInterface;

  /**
   * Get the language to use for EasyTransac API.
   */
  public function getLanguage(): string;

  /**
   * Prepare the EasyTransac API client.
   *
   * @param string $api_key
   *   The EasyTransac API key.
   */
  public function initClient(string $api_key): Services;

}
