<?php

namespace Drupal\commerce_easytransac\PluginForm\EasyTransac;

use Drupal\commerce_easytransac\Plugin\Commerce\PaymentGateway\PayByBankInterface;
use Drupal\commerce_payment\Exception\PaymentGatewayException;
use Drupal\Core\Form\FormStateInterface;
use EasyTransac\Entities\PayByBank;
use EasyTransac\Requests\PayByBank as PayByBankRequest;

/**
 * Provides the off-site form for EasyTransac PayByBank checkout (specific process).
 */
class PayByBankOffsiteForm extends AbstractOffsiteForm {

  /**
   * {@inheritdoc}
   */
  public function buildConfigurationForm(array $form, FormStateInterface $form_state) {
    $form = parent::buildConfigurationForm($form, $form_state);

    /** @var \Drupal\commerce_payment\Entity\PaymentInterface $payment */
    $payment = $this->entity;
    $order = $payment->getOrder();

    /** @var \Drupal\commerce_payment\Plugin\Commerce\PaymentGateway\OffsitePaymentGatewayInterface $payment_gateway_plugin */
    $payment_gateway_plugin = $payment->getPaymentGateway()->getPlugin();
    if (!($payment_gateway_plugin instanceof PayByBankInterface)) {
      throw new \UnexpectedValueException('Payment gateway must implement PayByBankInterface.');
    }

    $customer = \Drupal::service('commerce_easytransac.easytransac')
      ->getCustomer($order);

    // Define the existing EasyTransac client ID when possible.
    if (!empty($customer_remote_id = $payment_gateway_plugin->getRemoteCustomerId($order->getCustomer()))) {
      $customer->setClientId($customer_remote_id);
    }

    $amount = \Drupal::service('commerce_price.minor_units_converter')
      ->toMinorUnits($order->getTotalPrice());

    $transaction = (new PayByBank())
      ->setAmount($amount)
      ->setClientIP($order->getIpAddress())
      ->setDescription((string) $this->t('Payment of order #@id', ['@id' => $order->id()]))
      ->setCustomer($customer)
      ->setOrderId($order->id())
      ->setReturnUrl($form['#return_url'])
      ->setLanguage($payment_gateway_plugin->getApplication()->getLanguage());

    $payment_gateway_plugin->getClient();
    $response = (new PayByBankRequest())->execute($transaction);
    if (!$response->isSuccess()) {
      throw new PaymentGatewayException($response->getErrorMessage());
    }

    // Save the transaction identifier in the order for reference.
    /** @var \EasyTransac\Entities\DoneTransaction $transaction */
    $transaction = $response->getContent();
    $redirect_url = $transaction->getRedirectUrl();
    $order->setData('easytransac_transaction_identifier', $transaction->getTid());
    $order->setData('easytransac_redirect_url', $redirect_url);
    $order->save();

    return $this->buildRedirectForm($form, $form_state, $redirect_url, [], self::REDIRECT_GET);
  }

}
